Logging decorators
==================

.. currentmodule:: tango

LogIt
-----

.. autoclass:: tango.LogIt
    :members:

DebugIt
-------

.. autoclass:: tango.DebugIt
    :members:

InfoIt
------

.. autoclass:: tango.InfoIt
    :members:

WarnIt
-------

.. autoclass:: tango.WarnIt
    :members:

ErrorIt
-------

.. autoclass:: tango.ErrorIt
    :members:

FatalIt
-------

.. autoclass:: tango.FatalIt
    :members:
